﻿using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Cells;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
//using Syncfusion.UI.Xaml.Grid.Helpers;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Reflection;
using Syncfusion.Data;
using Syncfusion.Data.Extensions;
using System.Collections;
using System.Linq.Expressions;
using System.ComponentModel;

namespace SfDataGridDemo
{   
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {         
            InitializeComponent();
            this.datagrid.CellRenderers.Remove("TextBox");
            this.datagrid.CellRenderers.Add("TextBoxExt", new CerebroTextBoxBaseGridCellRenderer());           
        }

        private void datagrid_AutoGeneratingColumn(object sender, AutoGeneratingColumnArgs e)
        {
            e.Column = new CerebroTextColumn() { MappingName = "Value.DisplayValue" };
        }       
    }  
   
    public class CerebroTextColumn : GridTextColumn
    {
        private string propertyvalue="Value";
        public string Propertyvalue
        {
            get
            {
                return propertyvalue;
            }
            set
            {
                propertyvalue = value;
            } 
        }
        public CerebroTextColumn()
        {
            SetCellType("TextBoxExt");
        }       
    }

    public class CerebroTextBoxBaseGridCellRenderer : GridVirtualizingCellRenderer<TextBox, TextBox>
    {
        protected override TextBox OnCreateDisplayUIElement()
        {
            TextAlignmentToHorizontalAlignment(TextAlignment.Center);
            return new TextBox();
        }

        protected override TextBox OnCreateEditUIElement()
        {
            return new TextBox();
        }

        protected virtual void InitAppearence(TextBox element)
        {
            element.BorderThickness = new Thickness(0);
            element.FontSize = 14;

            element.Padding = new Thickness(1, 2, 1, 2);
            element.TextAlignment = TextAlignment.Center;
            element.HorizontalAlignment = HorizontalAlignment.Stretch;
            //element.Width = 105;
        }


        public override void OnInitializeDisplayElement(DataColumnBase dataColumn, TextBox uiElement, object dataContext)
        {
            InitAppearence(uiElement);

            SetDisplayBinding(uiElement, dataColumn.GridColumn, dataContext);
        }

        public virtual void SetDisplayBinding(TextBox element, GridColumn column, object dataContext)
        {
            var customColumn = (CerebroTextColumn)column;

            var binding = new System.Windows.Data.Binding
            {
                Path = new PropertyPath(customColumn.Propertyvalue + ".DisplayValue"),
                Source = dataContext,
                UpdateSourceTrigger = UpdateSourceTrigger.PropertyChanged,
                Converter = new NumberConverter()
            };

            element.SetBinding(TextBox.TextProperty, binding);
           

            var fgBinding = new System.Windows.Data.Binding
            {
                Path = new PropertyPath(customColumn.Propertyvalue + ".Foreground"),
                Source = dataContext,
            };

            element.SetBinding(TextBox.ForegroundProperty, fgBinding);

            var dgBinding = new System.Windows.Data.Binding
            {
                Path = new PropertyPath(customColumn.Propertyvalue + ".Background"),
                Source = dataContext,
            };

            element.SetBinding(TextBox.BackgroundProperty, dgBinding);
        }
    }

    public class NumberConverter : IValueConverter
    {

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }
}   

